#
# spec file for package libXv
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libXv
%define lname	libXv1
Version:        1.0.11
Release:        lp152.3.2
Summary:        X Video extension library
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXv
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXv/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(x11) >= 1.6
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8

%description
The X Video Extension (Xv) extension provides support for video
adaptors attached to an X display. It takes the approach that a
display may have one or more video adaptors, each of which has one or
more ports through which independent video streams pass.

%package -n %lname
Summary:        X Video extension library
Group:          System/Libraries
# O/P added for 12.2
Provides:       xorg-x11-libXv = 7.6_%version-%release
Obsoletes:      xorg-x11-libXv < 7.6_%version-%release

%description -n %lname
The X Video Extension (Xv) extension provides support for video
adaptors attached to an X display. It takes the approach that a
display may have one or more video adaptors, each of which has one or
more ports through which independent video streams pass.

Its use is to rescale video playback, do colorspace conversions, and
change contrast, brightness and hue using video controller hardware
acceleration.

%package devel
Summary:        Development files for the X Video extension library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
# O/P added for 12.2
Provides:       xorg-x11-libXv-devel = 7.6_%version-%release
Obsoletes:      xorg-x11-libXv-devel < 7.6_%version-%release

%description devel
The X Video Extension (Xv) extension provides support for video
adaptors attached to an X display. It takes the approach that a
display may have one or more video adaptors, each of which has one or
more ports through which independent video streams pass.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libXv.so.1*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXv.so
%_libdir/pkgconfig/xv.pc
%_mandir/man3/*

%changelog
* Wed Nov  2 2016 sndirsch@suse.com
- tagged baselibs.conf as source in specfile
* Fri Oct 28 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.11:
  + Fix typo in dependencies for lint library
  + Protocol handling issues in libXv - CVE-2016-5407
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.0.10:
  + Remove fallback for _XEatDataWords, require libX11 1.6 for it.
  + Refactor error handling.
  + Add missing calls to _XEatDataWords when we are skipping
    _XRead.
  + Replace custom copy of GetReq macro with call to Xlib 1.5's
    _XGetRequest.
  + Require ANSI C89 pre-processor, drop pre-C89 token pasting
    support.
  + Use pad_to_int32 macro instead of repeated (x + 3) & ~3
    pattern.
  + Fix sign conversion & comparison warnings from clang.
  + Remove unnecessary casts from Xmalloc calls.
  + Adopt X.Org standard code style, with consistent indentation.
* Sun Jun 23 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.9:
  This quick fix release corrects an issue with the security fix from 1.0.8,
  in which, if the size checks did determine the response from the X server
  was too large to fit in the buffer it had allocated, XvQueryPortAttributes
  could return a pointer to the caller that pointed to uninitialized memory
  where the caller expected a nil-terminated string.
* Sat Jun  1 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.8:
  This release delivers the fixes for the recently announced security issues
  CVE-2013-1989 & CVE-2013-2066, plus a couple build configuration changes
  and man page fixes.
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.7:
  + Janitorial cleanups
  + Man page fix
  + Build configuration improvements
* Sun Feb 12 2012 jengelh@medozas.de
- Rename xorg-x11-libXv to libXv and utilize shlib policy
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Sat Oct 30 2010 sndirsch@novell.com
- libXv 1.0.6
  * This minor maintenance release provides the usual recent
    collection of build configuration improvements and janitorial
    cleanups.
* Sun Apr  4 2010 sndirsch@suse.de
- libXv 1.0.5
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sat May  2 2009 eich@suse.de
- revert static library and .la file removal
  for SUSE versions <= 11.1.
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Mar 18 2008 sndirsch@suse.de
- libXv 1.0.4
  * nuke RCS Ids
  * get rid of ancient XFree86 CVS Id tags
  * convert manpages prototypes to C ANSI format
* Sat Jan 12 2008 crrodriguez@suse.de
- fix library-without-ldconfig* errors
- PreReq coreutils in -devel package
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Mon Dec 18 2006 sndirsch@suse.de
- updated to release 1.0.3
  * Makefile.am: make ChangeLog hook safer
* Thu Oct 26 2006 sndirsch@suse.de
- set version to 7.2 in specfile
* Mon Oct  9 2006 sndirsch@suse.de
- updated to release 1.0.2:
  * Minor cleanup release - fixes to documentation, lint/sparse
    warning cleanups, and closed a small memory leak Coverity
    found in the out-of-memory error handling path.
* Wed Aug  2 2006 sndirsch@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Sat Jun 24 2006 sndirsch@suse.de
- created package
